@@ -1,7 +1,7 @@
 import pytest
 
 from jaseci.utils.test_core import CoreTest, jac_testcase
-from jaseci.actions.live_actions import load_module_actions, unload_module
+from jaseci.jsorc.live_actions import load_module_actions, unload_module
 
 
 class TextClusterModule(CoreTest):
