@@ -1,4 +1,4 @@
-from jaseci.actions.live_actions import jaseci_action
+from jaseci.jsorc.live_actions import jaseci_action
 
 
 @jaseci_action(act_group=["example_module"], allow_remote=True)
@@ -7,6 +7,6 @@ def call(a: str):
 
 
 if __name__ == "__main__":
-    from jaseci.actions.remote_actions import launch_server
+    from jaseci.jsorc.remote_actions import launch_server
 
     launch_server(port=8000)
